@@ -18,6 +18,7 @@ The compression process is carried out internally by Blosc,
 a high-performance compressor that is optimized for binary data.
 
 """
+from pkg_resources import parse_version
 
 # Filters
 NOSHUFFLE = 0
@@ -29,16 +30,27 @@ filters = {NOSHUFFLE: "noshuffle",
            SHUFFLE: "shuffle",
            BITSHUFFLE: "bitshuffle"}
 
-min_numexpr_version = '1.4.1'  # the minimum version of Numexpr needed
+min_numexpr_version = '2.5.2'  # the minimum version of Numexpr needed
 numexpr_here = False
 try:
     import numexpr
 except ImportError:
     pass
 else:
-    if numexpr.__version__ >= min_numexpr_version:
+    if parse_version(numexpr.__version__) >= parse_version(min_numexpr_version):
         numexpr_here = True
 
+# Check for dask (as another virtual machine for chunked eval)
+min_dask_version = '0.9.0'  # the minimum version of Numexpr needed
+dask_here = False
+try:
+    import dask
+except ImportError:
+    pass
+else:
+    if parse_version(dask.__version__) >= parse_version(min_dask_version):
+        dask_here = True
+
 # Check for pandas (for data container conversion purposes)
 pandas_here = False
 try:
@@ -71,7 +83,7 @@ from bcolz.toplevel import (
     open, fromiter, arange, zeros, ones, fill,
     iterblocks, cparams, walk)
 from bcolz.chunked_eval import eval
-from bcolz.defaults import defaults
+from bcolz.defaults import defaults, defaults_ctx
 from bcolz.version import version as __version__
 
 try:
@@ -82,7 +94,7 @@ except ImportError:
               "If on Python2.6 please install unittest2")
 
 
-def _get_git_descrtiption(path_):
+def _get_git_description(path_):
     """ Get the output of git-describe when executed in a given path. """
 
     # imports in function because:
@@ -109,7 +121,7 @@ def _get_git_descrtiption(path_):
     except subprocess.CalledProcessError:  # not in git repo
         pass
 
-git_description = _get_git_descrtiption(__path__[0])
+git_description = _get_git_description(__path__[0])
 
 # Initialization code for the Blosc and numexpr libraries
 _blosc_init()
